colour.models.dataset.rec_2020 Module — Colour 0.3.0 documentation

# colour.models.dataset.rec_2020 Module

## Rec. 2020 Colourspace

Defines the Rec. 2020 colourspace:

- `REC_2020_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.itu.int/dms_pubrec/itu-r/rec/bt/R-REC-BT.2020-0-201208-I!!PDF-E.pdf (Last accessed 13 April 2014)

`colour.models.dataset.rec_2020.` `REC_2020_PRIMARIES` = array([[ 0.708, 0.292], [ 0.17 , 0.797], [ 0.131, 0.046]])

  Rec. 2020 colourspace primaries.

  REC_2020_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.rec_2020.` `REC_2020_WHITEPOINT` = (0.31271, 0.32902)

  Rec. 2020 colourspace whitepoint.

  REC_2020_WHITEPOINT : tuple

`colour.models.dataset.rec_2020.` `REC_2020_TO_XYZ_MATRIX` = array([[ 6.36953507e-01, 1.44619185e-01, 1.68855854e-01], [ 2.62698339e-01, 6.78008766e-01, 5.92928953e-02], [ 4.99407097e-17, 2.80731358e-02, 1.06082723e+00]])

  Rec. 2020 colourspace to CIE XYZ colourspace matrix.

  REC_2020_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.rec_2020.` `XYZ_TO_REC_2020_MATRIX` = array([[ 1.71666343, -0.35567332, -0.25336809], [-0.66667384, 1.61645574, 0.0157683 ], [ 0.01764248, -0.04277698, 0.94224328]])

  CIE XYZ colourspace to Rec. 2020 colourspace matrix.

  XYZ_TO_REC_2020_MATRIX : array_like, (3, 3)

`colour.models.dataset.rec_2020.` `REC_2020_CONSTANTS` = {'alpha': <function <lambda> at 0x102e23578>, 'beta': <function <lambda> at 0x102e23848>}

  CIE XYZ constants.

  REC_2020_CONSTANTS : Structure

`colour.models.dataset.rec_2020.` `REC_2020_TRANSFER_FUNCTION`(value, is_10_bits_system=True)

  Transfer function from linear to Rec. 2020 colourspace.

  REC_2020_TRANSFER_FUNCTION : object

`colour.models.dataset.rec_2020.` `REC_2020_INVERSE_TRANSFER_FUNCTION`(value, is_10_bits_system=True)

  Inverse transfer function from Rec. 2020 colourspace to linear.

  REC_2020_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.rec_2020.` `REC_2020_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e29050>

  Rec. 2020 colourspace.

  REC_2020_COLOURSPACE : RGB_Colourspace